@@ -121,6 +121,16 @@ pub struct CallStack {
     pub info: CallStackInfo,
     /// The name of the thread, if known.
     pub thread_name: Option<String>,
+    /// The GetLastError() value stored in the TEB.
+    pub last_error_value: Option<CrashReason>,
+}
+
+#[derive(Debug, Default)]
+pub struct LinuxStandardBase {
+    pub id: String,
+    pub release: String,
+    pub codename: String,
+    pub description: String,
 }
 
 /// The state of a process as recorded by a `Minidump`.
@@ -162,7 +172,7 @@ pub struct ProcessState {
     /// Information about the system on which the minidump was written.
     pub system_info: SystemInfo,
     /// Linux Standard Base Info
-    pub linux_standard_base: Option<MinidumpLinuxLsbRelease>,
+    pub linux_standard_base: Option<LinuxStandardBase>,
     pub mac_crash_info: Option<Vec<RawMacCrashInfo>>,
     /// The modules that were loaded into the process represented by the
     /// `ProcessState`.
@@ -308,6 +318,7 @@ impl CallStack {
             info,
             frames: vec![],
             thread_name: None,
+            last_error_value: None,
         }
     }
 
@@ -596,7 +607,7 @@ Unknown streams encountered:
                 "cpu_count": sys.cpu_count,
                 // TODO: Issue #19
                 // optional
-                "cpu_microcode_version": null,
+                "cpu_microcode_version": sys.cpu_microcode_version,
             },
             "crash_info": {
                 "type": self.crash_reason.map(|reason| reason.to_string()),
@@ -678,7 +689,7 @@ Unknown streams encountered:
                 "total_frames": thread.frames.len(),
                 // TODO: Issue #156
                 // optional
-                "last_error_value": null,
+                "last_error_value": thread.last_error_value.map(|error| error.to_string()),
                 // optional
                 "thread_name": thread.thread_name,
                 "frames": thread.frames.iter().enumerate().map(|(idx, frame)| json!({
